@@ -1,6 +1,6 @@
 # This file is part of bugzillatools
+# Copyright (C) 2011, 2012, 2013 Fraser Tweedale
 # Copyright (C) 2011, 2012 Benon Technologies Pty Ltd
-# Copyright (C) 2011, 2012 Fraser Tweedale
 #
 # bugzillatools is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -475,21 +475,23 @@ class Fields(BugzillaCommand):
         args = self._args
         fields = filter(lambda x: 'values' in x, self.bz.get_fields())
         for field in fields:
-            keyfn = lambda x: x['visibility_values']
+            keyfn = lambda x: x.get('visibility_values')
             groups = itertools.groupby(
                 sorted(field['values'], None, keyfn),
                 keyfn
             )
             print field['name'], ':'
             for key, group in groups:
-                values = sorted(group, None, lambda x: int(x['sortkey']))
+                keyfn = lambda x: int(x.get('sortkey', -1))
+                values = sorted(group, None, keyfn)
                 if key:
                     print '  {}: {}'.format(
-                        key,
+                        ','.join(key),
                         ','.join(map(lambda x: x['name'], values))
                     )
                 else:
-                    print '  ', ','.join(map(lambda x: x['name'], values))
+                    value_names = (v.get('name') for v in values)
+                    print '  ', ','.join(s for s in value_names if s)
 
 
 def _format_history(history):
@@ -558,7 +560,11 @@ class New(BugzillaCommand):
 
         # get mandatory fields
         fields = self.bz.get_fields()
-        mandatory_fields = filter(lambda x: x['is_mandatory'], fields)
+        defaulted_fields = [
+            'description', 'op_sys', 'rep_platform', 'priority', 'severity']
+        mandatory_fields = filter(
+            lambda x: x['is_mandatory'] or x['name'] in defaulted_fields,
+            fields)
 
         # first choose the product
         products = [x['name'] for x in self.bz.get_products()]
@@ -599,7 +605,7 @@ class New(BugzillaCommand):
         # (this info is not introspectable as of Bugzilla 4.0)
         create_fields = [
             'product', 'component', 'summary', 'version', 'comment',
-            'op_sys', 'platform', 'priority', 'severity', 'alias',
+            'op_sys', 'rep_platform', 'priority', 'severity', 'alias',
             'assigned_to', 'cc', 'comment_is_private', 'groups',
             'qa_contact', 'status', 'target_milestone',
         ]
